@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05-rc';
 
 =head1 NAME
 
@@ -11,7 +11,7 @@ Finance::Asset - Object representation of a financial asset
 
 =head1 VERSION
 
-1.04
+1.05
 
 =head1 SYNOPSYS
 
@@ -88,6 +88,17 @@ has pip_size => (
     default => 0.0001,
 );
 
+=head2 market
+
+The financial market to which this asset belongs
+
+=cut
+
+has market => (
+    is => 'ro',
+    isa => 'Str',
+);
+
 =head2 display_name
 
 User friendly name for the asset
